#!/usr/bin/python
# coding:utf-8

# pyweathercn - __init__.py
# 2018/5/23 16:32
# 

__author__ = 'Benny <benny@bennythink.com>'

import pyweathercn.helper


class Weather:
    """
    Weather broadcast class.
    Usage:
    1. chain call:`pyweathercn.Weather('重庆').temp()`
    2. instance mode: ```  w = pyweathercn.Weather('北京')
                            w.data```
    """

    def __init__(self, city_name):
        self.data = pyweathercn.helper.make_json(city_name)

    def __del__(self):
        del self.data

    def today(self, raw=False):
        """
        return today weather
        :param raw: return raw json
        :return: json or string.
        """
        return self.__return_result__(raw, 0)

    def tomorrow(self, raw=False):
        return self.__return_result__(raw, 1)

    def two_days(self, raw=False):
        return self.__return_result__(raw, 2)

    def three_days(self, raw=False):
        return self.__return_result__(raw, 3)

    def aqi(self, raw=False):
        return self.__make__(raw, 'aqi', 'AQI')

    def temp(self, raw=False):
        return self.__make__(raw, 'temp', '')

    def tip(self, raw=False):
        return self.__make__(raw, 'tip', '温馨提示')

    def forecast(self, raw=False, day=0):
        """
        forecast in assigning days. 0 stands for today, 1 for tomorrow. the number could be no larger than 6.
        :param raw: raw json
        :param day: day option. Default is 0 which will return today's weather information.
        :return: json response
        """
        if raw and self.data['status'] == 0:
            return self.data['data']['forecast'][day]
        elif self.data['status'] == 0:
            return self.data['data']['city'] + '：' + self.__make_str__(self.data['data']['forecast'][day])
        else:
            return self.data['desc']

    def __make__(self, raw, _type, text):
        """
        make specified json
        :param raw: raw json or not
        :param _type: aqi, temp or tip?
        :param text: default tooltip
        :return: json response.
        """
        if raw and self.data['status'] == 0:
            return self.data['data'][_type]

        elif self.data['status'] == 0:
            return self.data['data']['city'] + text + "：" + self.data['data'][_type]
        else:
            return self.data['desc']

    def __return_result__(self, raw, index):
        """
        today, tomorrow, two_days, three_days.
        :param raw: set True to return raw json, otherwise it shall return plain string.
        :param index: index for forecast function.
        :return: response.
        """
        if raw and self.data['status'] == 0:
            return self.data['data']['forecast'][index]
        elif self.data['status'] == 0:
            return self.data['data']['city'] + '：' + self.__make_str__(self.data['data']['forecast'][index])
        else:
            return self.data['desc']

    @staticmethod
    def __make_str__(dic):
        s = ''
        for i in dic:
            s = s + dic[i]
        return s


def server(port=8888, host="127.0.0.1", **kwargs):
    """
    run RESTAPI server.
    :param port: the port to listen on. Default is 8888
    :param host: the host to listen on. Default is localhost.
    :param kwargs: any keyword argument support by tornado. example for SSL:
    ```ssl_options={
        "certfile": "fullchain.pem",
        "keyfile": "privkey.pem"}
    ```
    :return: None
    """
    pyweathercn.helper.run_server(port, host, **kwargs)



#!/usr/bin/python
# coding:utf-8

# pyweathercn - helper.py
# 2018/5/22 16:32
# 

__author__ = 'Benny <benny@bennythink.com>'

import json

import tornado.ioloop
import tornado.web

from pyweathercn.craw import make_json


class MainHandler(tornado.web.RequestHandler):
    def get(self):
        self.set_header("Content-Type", "application/json")
        self.write(self.process(self))

    def post(self):
        self.set_header("Content-Type", "application/json")
        self.write(self.process(self))

    @staticmethod
    def process(self):
        # get parameter

        city = self.get_argument('city', None)
        day = self.get_argument('day', None)

        # mandatory param missing
        if city is None:
            return make_json(4)
        # day, return specified day.
        elif day:
            data = make_json(city)
            try:
                sp = data['data']['forecast'][int(day)]
            except IndexError:
                sp = {"status": 3, "desc": 'day out of range'}
            return json.dumps(sp)
        # return whole json.
        else:
            return json.dumps(make_json(city))


def make_app():
    return tornado.web.Application([
        (r"/weather", MainHandler),
    ])


def run_server(port, host, **kwargs):
    app = make_app()
    app.listen(port, host, **kwargs)
    print('%s running on %s' % (host, port))
    tornado.ioloop.IOLoop.current().start()


if __name__ == "__main__":
    run_server('8888', 'api.serversan.date', ssl_options={
        "certfile": "fullchain.pem",
        "keyfile": "privkey.pem"})



#!/usr/bin/env python
# Learn more: https://github.com/kennethreitz/setup.py

# Note: To use the 'upload' functionality of this file, you must:
#   $ pip install twine

import io
import os

from distutils.core import setup

# Package meta-data.
NAME = 'pyweathercn'
DESCRIPTION = 'A package to use weather.com.cn forecast'
URL = 'https://github.com/BennyThink/pyweathercn'
EMAIL = 'benny@bennythink.com'
AUTHOR = 'BennyThink'
REQUIRES_PYTHON = '>=3.5.0'
VERSION = None

# What packages are required for this module to be executed?
REQUIRED = [
    "tornado",
    "beautifulsoup4",
    "requests"
]

# The rest you shouldn't have to touch too much :)
# ------------------------------------------------
# Except, perhaps the License and Trove Classifiers!
# If you do change the License, remember to change the Trove Classifier for that!

here = os.path.abspath(os.path.dirname(__file__))

# Import the README.md and use it as the long-description.
# Note: this will only work if 'README.md' is present in your MANIFEST.in file!
with io.open(os.path.join(here, 'README.rst'), encoding='utf-8') as f:
    long_description = '\n' + f.read()

# Load the package's __version__.py module as a dictionary.
about = {}
if not VERSION:
    with open(os.path.join(here, NAME, '__version__.py')) as f:
        exec(f.read(), about)
else:
    about['__version__'] = VERSION

# Where the magic happens:
setup(
    name=NAME,
    version=about['__version__'],
    description=DESCRIPTION,
    long_description=long_description,
    # long_description_content_type='text/markdown',
    author=AUTHOR,
    author_email=EMAIL,
    python_requires=REQUIRES_PYTHON,
    url=URL,
    packages=['pyweathercn'],
    install_requires=REQUIRED,
    license='MIT',
    classifiers=[
        # Trove classifiers
        # Full list: https://pypi.python.org/pypi?%3Aaction=list_classifiers
        'License :: OSI Approved :: MIT License',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy'
    ],

)
